@@ -1,6 +1,7 @@
 """
 从 HTTP Header 中获取的信息
 """
+import warnings
 from typing import Optional
 
 from django.http import HttpRequest
@@ -12,6 +13,8 @@ def get_client_ip(request: HttpRequest) -> Optional[str]:
     """
     获取用户的 IP 地址
     """
+    # https://github.com/un33k/django-ipware
+    warnings.warn("use django-ipware plugin replace this", DeprecationWarning)
 
     x: str = request.META.get("HTTP_X_FORWARDED_FOR", None)
     if x:
